pub struct FlipBasedDirection {
pub left_direction_is_flipped: bool,
pub x_direction_index: usize,
}Expand description
Used to define the direction index. If you don’t have sprites with multiple directions this will
flip them when the AnimationDirection changes
Note if you have each direction already in a sprite sheet use IndexBasedDirection as it
is functionally more proper
Fields
left_direction_is_flipped: boolTo Determine if the Left Facing Sprites are Left Facing When Flipped or Not
x_direction_index: usizeTo Determine which y-index the Horizontal Directions Sprites. 0th index Based